@@ -1,8 +1,10 @@
+from typing import get_args
 import warnings
 
 from django.conf import settings as django_settings
+from django.utils.module_loading import import_string
 
-from gqlauth.settings_type import DjangoSetting, GqlAuthSettings
+from gqlauth.settings_type import DjangoSetting, GqlAuthSettings, ImportString
 
 gqlauth_settings: GqlAuthSettings = None
 
@@ -26,4 +28,7 @@ for name, setting in gqlauth_settings.__dataclass_fields__.items():
     value = getattr(gqlauth_settings, name)
     if setting.type is DjangoSetting and value is getattr(defaults, name):
         setattr(gqlauth_settings, name, value())
+    elif ImportString in get_args(setting.type) and isinstance(value, str):
+        setattr(gqlauth_settings, name, import_string(value))
+
 del defaults
